#!/bin/bash
COM_ERR=1
INSTALL_DIR=/opt/ups
CONF_FILE=ups.conf
LIB=ups.lib
USB_LOW=0
X=0

source $INSTALL_DIR/$CONF_FILE


#If UPS is not present, we exit so that we don't keep accessing it via I2C
sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -is_ups_connected
if [ $? -ne 1 ]
then
	echo "UPS not detected, stopping poweroff monitor"
	logger UPS: not detected, stopping poweroff monitor
	exit 0
else
	logger UPS: Power turned on
fi


#Every second, check if UPS is in the process of powering down due to a button press or low batteries.
#If yes then call poweroff to safety shut down the Raspberry Pi.
#Also log important events to /var/log/messages

while :


do
	#Check if UPS is powering down
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -is_powering_off
	X=$?
		
	if [ $X -ne 0 ]
	then
		echo "Calling sudo poweroff" | wall
		
		if [ $X -eq 1 ]
		then
			logger UPS: Shutting down, button press
		elif [ $X -eq 2 ]
		then
			logger UPS: Shutting down, USB and battery voltage low
		elif [ $X -eq 3 ]
		then
			logger UPS: Shutting down, Rasperry Pi 5V low, could be overcurrent
		elif [ $X -eq 4 ]
		then
			logger UPS: Shutting down, power_cycle call
		elif [ $X -eq 5 ]
		then
			logger UPS: Shutting down, power_off call
		else
			logger UPS: Shutting down, unknown event $X	
		fi
		sleep 1
		
		
		#User code before poweroff can be placed here
		
		sudo poweroff
	fi
	
	#Check if USB power just went low, or just just came back
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -is_usb_low	
	X=$?
	
	if [ $X -eq 1 ] && [ $USB_LOW -eq 0 ]
	then
		logger UPS: USB power low, switching to battery power
		USB_LOW=1
	fi
	
	if [ $X -eq 0 ] && [ $USB_LOW -eq 1 ]
	then
		logger UPS: USB power okay
		USB_LOW=0
	fi
	
	
	sleep 1
done

